print("import: 'PyQt5.QtCore'")
import PyQt5.QtCore

print("import: 'PyQt5.QtGui'")
import PyQt5.QtGui

print("import: 'PyQt5.QtHelp'")
import PyQt5.QtHelp

print("import: 'PyQt5.QtMultimedia'")
import PyQt5.QtMultimedia

print("import: 'PyQt5.QtMultimediaWidgets'")
import PyQt5.QtMultimediaWidgets

print("import: 'PyQt5.QtNetwork'")
import PyQt5.QtNetwork

print("import: 'PyQt5.QtOpenGL'")
import PyQt5.QtOpenGL

print("import: 'PyQt5.QtPrintSupport'")
import PyQt5.QtPrintSupport

print("import: 'PyQt5.QtQml'")
import PyQt5.QtQml

print("import: 'PyQt5.QtQuick'")
import PyQt5.QtQuick

print("import: 'PyQt5.QtSvg'")
import PyQt5.QtSvg

print("import: 'PyQt5.QtTest'")
import PyQt5.QtTest

print("import: 'PyQt5.QtWebChannel'")
import PyQt5.QtWebChannel

print("import: 'PyQt5.QtWebEngineWidgets'")
import PyQt5.QtWebEngineWidgets

print("import: 'PyQt5.QtWebSockets'")
import PyQt5.QtWebSockets

print("import: 'PyQt5.QtWidgets'")
import PyQt5.QtWidgets

print("import: 'PyQt5.QtXml'")
import PyQt5.QtXml

print("import: 'PyQt5.QtXmlPatterns'")
import PyQt5.QtXmlPatterns

